@@ -6,10 +6,9 @@ class I18nLDPViewSet(LDPViewSet):
     '''
     Overrides LDPViewSet to use custom serializer
     '''
+    serializer_class = I18nLDPSerializer
 
     def build_serializer(self, meta_args, name_prefix):
         meta_args['list_serializer_class'] = I18nContainerSerializer
-        meta_class = type('Meta', (), meta_args)
 
-        return type(I18nLDPSerializer)(self.model._meta.object_name.lower() + name_prefix + 'Serializer',
-                                       (I18nLDPSerializer,),{'Meta': meta_class})
\ No newline at end of file
+        return super(I18nLDPViewSet, self).build_serializer(meta_args, name_prefix)
